//
//  DetailViewController.m
//  ListMe
//
//  Created by Yili Aiwazian on 11/3/13.
//  Copyright (c) 2013 com.nickaiwazian. All rights reserved.
//

#import "DetailViewController.h"
#import "List.h"
#import "ListItem.h"
#import "ListItemInfo.h"
#import "CoreDataHelper.h"

@interface DetailViewController ()

@property (strong, nonatomic) CoreDataHelper *coreDataHelper;
@property (strong, nonatomic) List *parentList;
@property (strong, nonatomic) ListItem *parentListItem;

// Outlets
@property (weak, nonatomic) IBOutlet UIPickerView *parentListPicker;
@property (weak, nonatomic) IBOutlet UILabel *dueDateLabel;
@property (weak, nonatomic) IBOutlet UILabel *listNameLabel;
@property (weak, nonatomic) IBOutlet UITextView *notesTextView;

@end

@implementation DetailViewController

#pragma mark - UI

/**
 * Description: Update the view
 */

- (void)updateUI {
    
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateFormat:DateFormatLong];
    [formatter setTimeZone:[NSTimeZone timeZoneWithName:TimeZone]];

    self.title = self.parentListItem.name;
    self.dueDateLabel.text = [formatter stringFromDate:self.parentListItem.dueDate];
    self.listNameLabel.text = self.parentListItem.list.name;
    self.notesTextView.text = self.parentListItem.listItemInfo.notes;
}

#pragma mark - Controller

/**
 * Description: Back to list view button pressed
 */

- (IBAction)handleBack:(id)sender {
    
    // pop to root view controller
    [self.navigationController popToRootViewControllerAnimated:YES];
}

/**
 * Description: Configure the UI
 */

- (void)viewWillAppear:(BOOL)animated {
    
    [self updateUI];
    
//    TODO: Add the proper picker code back
 //   NSArray *lists = [self.coreDataHelper executeCoreDataQueryWithAlphabeticalSortFor:ListEntity with:nil andSortKey:ListName];
 //   NSUInteger index = [lists indexOfObject:self.parentList];
 //   [self.parentListPicker selectRow:index inComponent:0 animated:NO];

}

#pragma mark - Properties

/**
 * Description: Get the shared core data helper
 */

- (CoreDataHelper *)coreDataHelper {

    if( !_coreDataHelper )
        _coreDataHelper = CoreDataHelper.sharedCoreDataHelper;
    
    return _coreDataHelper;
}

/**
 * Description: Update the parent list
 */

- (void)setParentList:(List *)parentList {

    _parentList = parentList;
}

/**
 * Description: Set the list item, set the parent list, and update the UI
 */

- (void)setParentListItem:(ListItem *)parentListItem {

    _parentListItem = parentListItem;
    
    // Update the parent list
    self.parentList = parentListItem.list;
    
    // Update the view.
    [self updateUI];
}

#pragma mark - List Picker

/**
 * Description: Always display one column
 */

- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView {
    
    return 1;
}

/**
 * Description: Get the number of lists
 */

- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component {

    NSUInteger count = [self.coreDataHelper executeCountOfCoreDataQueryFor:ListEntity with:nil];
    return count;
}

/**
 * Description: Set the list name for each row
 */

- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component {

    NSArray *lists = [self.coreDataHelper executeCoreDataQueryWithAlphabeticalSortFor:ListEntity
                                                                                 with:nil
                                                                           andSortKey:ListName];
    List *list = lists[row];
    
    return list.name;
}

//TODO: Implement this after we layout picker properly
- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component {
    
}

@end
